/*
 * Copyright (c) 2020 Texas Instruments Incorporated - http://www.ti.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef BOARD_H
#define BOARD_H

//*****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//*****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//
// Included Files
//

#include "driverlib.h"
#include "device.h"

//*****************************************************************************
//
// PinMux Configurations
//
//*****************************************************************************

//
// CANA -> myCAN0 Pinmux
//
//
// CANRXA - GPIO Settings
//
#define GPIO_PIN_CANRXA 62
#define myCAN0_CANRX_GPIO 62
#define myCAN0_CANRX_PIN_CONFIG GPIO_62_CANRXA
//
// CANTXA - GPIO Settings
//
#define GPIO_PIN_CANTXA 63
#define myCAN0_CANTX_GPIO 63
#define myCAN0_CANTX_PIN_CONFIG GPIO_63_CANTXA

//
// EPWM2 -> myEPWM0 Pinmux
//
//
// EPWM2A - GPIO Settings
//
#define GPIO_PIN_EPWM2A 2
#define myEPWM0_EPWMA_GPIO 2
#define myEPWM0_EPWMA_PIN_CONFIG GPIO_2_EPWM2A
//
// EPWM2B - GPIO Settings
//
#define GPIO_PIN_EPWM2B 3
#define myEPWM0_EPWMB_GPIO 3
#define myEPWM0_EPWMB_PIN_CONFIG GPIO_3_EPWM2B

//
// EPWM6 -> myEPWM1 Pinmux
//
//
// EPWM6A - GPIO Settings
//
#define GPIO_PIN_EPWM6A 10
#define myEPWM1_EPWMA_GPIO 10
#define myEPWM1_EPWMA_PIN_CONFIG GPIO_10_EPWM6A
//
// EPWM6B - GPIO Settings
//
#define GPIO_PIN_EPWM6B 11
#define myEPWM1_EPWMB_GPIO 11
#define myEPWM1_EPWMB_PIN_CONFIG GPIO_11_EPWM6B

//
// EPWM7 -> myEPWM2 Pinmux
//
//
// EPWM7A - GPIO Settings
//
#define GPIO_PIN_EPWM7A 12
#define myEPWM2_EPWMA_GPIO 12
#define myEPWM2_EPWMA_PIN_CONFIG GPIO_12_EPWM7A
//
// EPWM7B - GPIO Settings
//
#define GPIO_PIN_EPWM7B 13
#define myEPWM2_EPWMB_GPIO 13
#define myEPWM2_EPWMB_PIN_CONFIG GPIO_13_EPWM7B

//
// EPWM8 -> myEPWM3 Pinmux
//
//
// EPWM8A - GPIO Settings
//
#define GPIO_PIN_EPWM8A 14
#define myEPWM3_EPWMA_GPIO 14
#define myEPWM3_EPWMA_PIN_CONFIG GPIO_14_EPWM8A
//
// EPWM8B - GPIO Settings
//
#define GPIO_PIN_EPWM8B 15
#define myEPWM3_EPWMB_GPIO 15
#define myEPWM3_EPWMB_PIN_CONFIG GPIO_15_EPWM8B

//
// EPWM9 -> myEPWM4 Pinmux
//
//
// EPWM9A - GPIO Settings
//
#define GPIO_PIN_EPWM9A 16
#define myEPWM4_EPWMA_GPIO 16
#define myEPWM4_EPWMA_PIN_CONFIG GPIO_16_EPWM9A
//
// EPWM9B - GPIO Settings
//
#define GPIO_PIN_EPWM9B 17
#define myEPWM4_EPWMB_GPIO 17
#define myEPWM4_EPWMB_PIN_CONFIG GPIO_17_EPWM9B
//
// GPIO84 - GPIO Settings
//
#define myGPIO0_GPIO_PIN_CONFIG GPIO_84_GPIO84
//
// GPIO85 - GPIO Settings
//
#define myGPIO1_GPIO_PIN_CONFIG GPIO_85_GPIO85
//
// GPIO86 - GPIO Settings
//
#define myGPIO2_GPIO_PIN_CONFIG GPIO_86_GPIO86
//
// GPIO18 - GPIO Settings
//
#define myGPIO3_GPIO_PIN_CONFIG GPIO_18_GPIO18
//
// GPIO19 - GPIO Settings
//
#define myGPIO4_GPIO_PIN_CONFIG GPIO_19_GPIO19
//
// GPIO20 - GPIO Settings
//
#define myGPIO5_GPIO_PIN_CONFIG GPIO_20_GPIO20
//
// GPIO21 - GPIO Settings
//
#define myGPIO6_GPIO_PIN_CONFIG GPIO_21_GPIO21

//
// I2CA -> myI2C0 Pinmux
//
//
// SDAA - GPIO Settings
//
#define GPIO_PIN_SDAA 42
#define myI2C0_I2CSDA_GPIO 42
#define myI2C0_I2CSDA_PIN_CONFIG GPIO_42_SDAA
//
// SCLA - GPIO Settings
//
#define GPIO_PIN_SCLA 43
#define myI2C0_I2CSCL_GPIO 43
#define myI2C0_I2CSCL_PIN_CONFIG GPIO_43_SCLA

//*****************************************************************************
//
// ADC Configurations
//
//*****************************************************************************
#define myADC0_BASE ADCA_BASE
#define myADC0_RESULT_BASE ADCARESULT_BASE
#define myADC0_SOC0 ADC_SOC_NUMBER0
#define myADC0_FORCE_SOC0 ADC_FORCE_SOC0
#define myADC0_SAMPLE_WINDOW_SOC0 75
#define myADC0_TRIGGER_SOURCE_SOC0 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC0 ADC_CH_ADCIN0
#define myADC0_SOC1 ADC_SOC_NUMBER1
#define myADC0_FORCE_SOC1 ADC_FORCE_SOC1
#define myADC0_SAMPLE_WINDOW_SOC1 75
#define myADC0_TRIGGER_SOURCE_SOC1 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC1 ADC_CH_ADCIN1
#define myADC0_SOC2 ADC_SOC_NUMBER2
#define myADC0_FORCE_SOC2 ADC_FORCE_SOC2
#define myADC0_SAMPLE_WINDOW_SOC2 75
#define myADC0_TRIGGER_SOURCE_SOC2 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC2 ADC_CH_ADCIN2
#define myADC0_SOC3 ADC_SOC_NUMBER3
#define myADC0_FORCE_SOC3 ADC_FORCE_SOC3
#define myADC0_SAMPLE_WINDOW_SOC3 75
#define myADC0_TRIGGER_SOURCE_SOC3 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC3 ADC_CH_ADCIN3
#define myADC0_SOC4 ADC_SOC_NUMBER4
#define myADC0_FORCE_SOC4 ADC_FORCE_SOC4
#define myADC0_SAMPLE_WINDOW_SOC4 75
#define myADC0_TRIGGER_SOURCE_SOC4 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC4 ADC_CH_ADCIN4
#define myADC0_SOC5 ADC_SOC_NUMBER5
#define myADC0_FORCE_SOC5 ADC_FORCE_SOC5
#define myADC0_SAMPLE_WINDOW_SOC5 75
#define myADC0_TRIGGER_SOURCE_SOC5 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC5 ADC_CH_ADCIN0
void myADC0_init();

#define myADC1_BASE ADCB_BASE
#define myADC1_RESULT_BASE ADCBRESULT_BASE
#define myADC1_SOC0 ADC_SOC_NUMBER0
#define myADC1_FORCE_SOC0 ADC_FORCE_SOC0
#define myADC1_SAMPLE_WINDOW_SOC0 75
#define myADC1_TRIGGER_SOURCE_SOC0 ADC_TRIGGER_SW_ONLY
#define myADC1_CHANNEL_SOC0 ADC_CH_ADCIN0
#define myADC1_SOC1 ADC_SOC_NUMBER1
#define myADC1_FORCE_SOC1 ADC_FORCE_SOC1
#define myADC1_SAMPLE_WINDOW_SOC1 75
#define myADC1_TRIGGER_SOURCE_SOC1 ADC_TRIGGER_SW_ONLY
#define myADC1_CHANNEL_SOC1 ADC_CH_ADCIN1
#define myADC1_SOC2 ADC_SOC_NUMBER2
#define myADC1_FORCE_SOC2 ADC_FORCE_SOC2
#define myADC1_SAMPLE_WINDOW_SOC2 75
#define myADC1_TRIGGER_SOURCE_SOC2 ADC_TRIGGER_SW_ONLY
#define myADC1_CHANNEL_SOC2 ADC_CH_ADCIN2
#define myADC1_SOC3 ADC_SOC_NUMBER3
#define myADC1_FORCE_SOC3 ADC_FORCE_SOC3
#define myADC1_SAMPLE_WINDOW_SOC3 75
#define myADC1_TRIGGER_SOURCE_SOC3 ADC_TRIGGER_SW_ONLY
#define myADC1_CHANNEL_SOC3 ADC_CH_ADCIN3
#define myADC1_SOC4 ADC_SOC_NUMBER4
#define myADC1_FORCE_SOC4 ADC_FORCE_SOC4
#define myADC1_SAMPLE_WINDOW_SOC4 75
#define myADC1_TRIGGER_SOURCE_SOC4 ADC_TRIGGER_SW_ONLY
#define myADC1_CHANNEL_SOC4 ADC_CH_ADCIN4
#define myADC1_SOC5 ADC_SOC_NUMBER5
#define myADC1_FORCE_SOC5 ADC_FORCE_SOC5
#define myADC1_SAMPLE_WINDOW_SOC5 75
#define myADC1_TRIGGER_SOURCE_SOC5 ADC_TRIGGER_SW_ONLY
#define myADC1_CHANNEL_SOC5 ADC_CH_ADCIN5
#define myADC1_SOC6 ADC_SOC_NUMBER6
#define myADC1_FORCE_SOC6 ADC_FORCE_SOC6
#define myADC1_SAMPLE_WINDOW_SOC6 75
#define myADC1_TRIGGER_SOURCE_SOC6 ADC_TRIGGER_SW_ONLY
#define myADC1_CHANNEL_SOC6 ADC_CH_ADCIN14
#define myADC1_SOC7 ADC_SOC_NUMBER7
#define myADC1_FORCE_SOC7 ADC_FORCE_SOC7
#define myADC1_SAMPLE_WINDOW_SOC7 75
#define myADC1_TRIGGER_SOURCE_SOC7 ADC_TRIGGER_SW_ONLY
#define myADC1_CHANNEL_SOC7 ADC_CH_ADCIN15
void myADC1_init();


//*****************************************************************************
//
// CAN Configurations
//
//*****************************************************************************
#define myCAN0_BASE CANA_BASE

#define myCAN0_MessageObj1_ID 291
#define myCAN0_MessageObj2_ID 290
void myCAN0_init();


//*****************************************************************************
//
// CLA Configurations
//
//*****************************************************************************
#define myCLA0_BASE CLA1_BASE

//
// The following are symbols defined in the CLA assembly code
// Including them in the shared header file makes them global
// and the main CPU can make use of them.
//
__attribute__((interrupt)) void Cla1Task1();
__attribute__((interrupt)) void Cla1Task2();
__attribute__((interrupt)) void Cla1Task3();
__attribute__((interrupt)) void Cla1Task4();
__attribute__((interrupt)) void Cla1Task5();
__attribute__((interrupt)) void Cla1Task6();
__attribute__((interrupt)) void Cla1Task7();
__attribute__((interrupt)) void Cla1Task8();
void myCLA0_init();


//*****************************************************************************
//
// CPUTIMER Configurations
//
//*****************************************************************************
#define myCPUTIMER0_BASE CPUTIMER0_BASE
void myCPUTIMER0_init();

//*****************************************************************************
//
// EPWM Configurations
//
//*****************************************************************************
#define myEPWM0_BASE EPWM2_BASE
#define myEPWM0_TBPRD 2500
#define myEPWM0_COUNTER_MODE EPWM_COUNTER_MODE_UP_DOWN
#define myEPWM0_TBPHS 0
#define myEPWM0_CMPA 1225
#define myEPWM0_CMPB 1225
#define myEPWM0_CMPC 0
#define myEPWM0_CMPD 0
#define myEPWM0_DBRED 0
#define myEPWM0_DBFED 0
#define myEPWM0_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM0_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM0_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED
#define myEPWM1_BASE EPWM6_BASE
#define myEPWM1_TBPRD 2500
#define myEPWM1_COUNTER_MODE EPWM_COUNTER_MODE_UP_DOWN
#define myEPWM1_TBPHS 0
#define myEPWM1_CMPA 1225
#define myEPWM1_CMPB 1225
#define myEPWM1_CMPC 0
#define myEPWM1_CMPD 0
#define myEPWM1_DBRED 0
#define myEPWM1_DBFED 0
#define myEPWM1_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM1_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM1_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED
#define myEPWM2_BASE EPWM7_BASE
#define myEPWM2_TBPRD 2500
#define myEPWM2_COUNTER_MODE EPWM_COUNTER_MODE_UP_DOWN
#define myEPWM2_TBPHS 0
#define myEPWM2_CMPA 1225
#define myEPWM2_CMPB 1225
#define myEPWM2_CMPC 0
#define myEPWM2_CMPD 0
#define myEPWM2_DBRED 0
#define myEPWM2_DBFED 0
#define myEPWM2_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM2_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM2_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED
#define myEPWM3_BASE EPWM8_BASE
#define myEPWM3_TBPRD 2500
#define myEPWM3_COUNTER_MODE EPWM_COUNTER_MODE_UP_DOWN
#define myEPWM3_TBPHS 0
#define myEPWM3_CMPA 1225
#define myEPWM3_CMPB 1225
#define myEPWM3_CMPC 0
#define myEPWM3_CMPD 0
#define myEPWM3_DBRED 0
#define myEPWM3_DBFED 0
#define myEPWM3_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM3_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM3_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED
#define myEPWM4_BASE EPWM9_BASE
#define myEPWM4_TBPRD 2500
#define myEPWM4_COUNTER_MODE EPWM_COUNTER_MODE_UP_DOWN
#define myEPWM4_TBPHS 0
#define myEPWM4_CMPA 1225
#define myEPWM4_CMPB 1225
#define myEPWM4_CMPC 0
#define myEPWM4_CMPD 0
#define myEPWM4_DBRED 0
#define myEPWM4_DBFED 0
#define myEPWM4_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM4_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM4_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED

//*****************************************************************************
//
// GPIO Configurations
//
//*****************************************************************************
#define myGPIO0 84
void myGPIO0_init();
#define myGPIO1 85
void myGPIO1_init();
#define myGPIO2 86
void myGPIO2_init();
#define myGPIO3 18
void myGPIO3_init();
#define myGPIO4 19
void myGPIO4_init();
#define myGPIO5 20
void myGPIO5_init();
#define myGPIO6 21
void myGPIO6_init();

//*****************************************************************************
//
// I2C Configurations
//
//*****************************************************************************
#define myI2C0_BASE I2CA_BASE
#define myI2C0_BITRATE 400000
#define myI2C0_TARGET_ADDRESS 0
#define myI2C0_OWN_TARGET_ADDRESS 0
void myI2C0_init();

//*****************************************************************************
//
// INTERRUPT Configurations
//
//*****************************************************************************

// Interrupt Settings for INT_myCLA01
#define INT_myCLA01 INT_CLA1_1
#define INT_myCLA01_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP11
extern __interrupt void cla1Isr1(void);

// Interrupt Settings for INT_myCLA02
#define INT_myCLA02 INT_CLA1_2
#define INT_myCLA02_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP11
extern __interrupt void cla1Isr2(void);

// Interrupt Settings for INT_myCLA03
#define INT_myCLA03 INT_CLA1_3
#define INT_myCLA03_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP11
extern __interrupt void cla1Isr3(void);

// Interrupt Settings for INT_myCLA04
#define INT_myCLA04 INT_CLA1_4
#define INT_myCLA04_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP11
extern __interrupt void cla1Isr4(void);

// Interrupt Settings for INT_myCLA05
#define INT_myCLA05 INT_CLA1_5
#define INT_myCLA05_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP11
extern __interrupt void cla1Isr5(void);

// Interrupt Settings for INT_myCLA06
#define INT_myCLA06 INT_CLA1_6
#define INT_myCLA06_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP11
extern __interrupt void cla1Isr6(void);

// Interrupt Settings for INT_myCLA07
#define INT_myCLA07 INT_CLA1_7
#define INT_myCLA07_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP11
extern __interrupt void cla1Isr7(void);

// Interrupt Settings for INT_myCLA08
#define INT_myCLA08 INT_CLA1_8
#define INT_myCLA08_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP11
extern __interrupt void cla1Isr8(void);

// Interrupt Settings for INT_timer2
#define INT_timer2 INT_TIMER2
extern __interrupt void portTICK_ISR(void);

// Interrupt Settings for INT_myCAN0_0
#define INT_myCAN0_0 INT_CANA0
#define INT_myCAN0_0_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP9
extern __interrupt void INT_myCAN0_0_ISR(void);

// Interrupt Settings for INT_myCAN0_1
#define INT_myCAN0_1 INT_CANA1
#define INT_myCAN0_1_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP9
extern __interrupt void INT_myCAN0_1_ISR(void);

//*****************************************************************************
//
// MEMCFG Configurations
//
//*****************************************************************************

//*****************************************************************************
//
// SYNC Scheme Configurations
//
//*****************************************************************************

//*****************************************************************************
//
// Board Configurations
//
//*****************************************************************************
void	Board_init();
void	ADC_init();
void	CAN_init();
void	CLA_init();
void	CPUTIMER_init();
void	EPWM_init();
void	GPIO_init();
void	I2C_init();
void	INTERRUPT_init();
void	MEMCFG_init();
void	SYNC_init();
void	PinMux_init();

//*****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//*****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of BOARD_H definition
