/*
 * Copyright (C) 2021 Texas Instruments Incorporated - http://www.ti.com/
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 * the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef C2000_FREERTOS_H
#define C2000_FREERTOS_H

//
// Includes
//
#include "FreeRTOS.h"
#include "task.h"
#include "semphr.h"
#include "queue.h"
#include "timers.h"
#include "event_groups.h"
#include "driverlib.h"

extern uint8_t ucHeap[ 8192 ];

//
// Idle task specific macros
//
#define IDLE_TASK_STACK_SIZE configMINIMAL_STACK_SIZE

//
// Idle task specific variables
//
extern StaticTask_t idleTaskTCBBuffer;
extern StackType_t idleTaskStack[IDLE_TASK_STACK_SIZE];

//
// Macro for task stack size
//
#define myTask0_STACK_SIZE 256

//
// Variables for Task TCB and stack
//
extern StaticTask_t myTask0TCBBuffer;
extern StackType_t myTask0StackBuffer[myTask0_STACK_SIZE];

//
// Task Handle for task myTask0
//
extern TaskHandle_t myTask0Handle;

//
// Macro for task stack size
//
#define myTask1_STACK_SIZE 256

//
// Variables for Task TCB and stack
//
extern StaticTask_t myTask1TCBBuffer;
extern StackType_t myTask1StackBuffer[myTask1_STACK_SIZE];

//
// Task Handle for task myTask1
//
extern TaskHandle_t myTask1Handle;

//
// Declaration for Task function. Application needs to implement this.
//
extern void mcu_task1( void * pvParameters );
//
// Declaration for Task function. Application needs to implement this.
//
extern void mcu_task2( void * pvParameters );

//
// Init Functions
//
void myTask0_init();
void myTask1_init();
void vApplicationGetIdleTaskMemory( StaticTask_t **ppxIdleTaskTCBBuffer,
                                    StackType_t **ppxIdleTaskStackBuffer,
                                    uint32_t *pulIdleTaskStackSize );
void vApplicationSetupTimerInterrupt( void );
void FreeRTOS_init();

#endif /* C2000_FREERTOS_H */

