//###########################################################################

//
// Included Files
//
#include <hal_gpio.h>
#include "driverlib.h"
#include "board.h"
#include "FreeRTOS.h"
#include "c2000_freertos.h"
#include "FreeRTOSConfig.h"

// inc files to use till ASW is not ready
//#include "hal_adc.h"
//#include "hal_gpio.h"
//#include "hal_pwm.h"

//
// Defines
//
#define WAITSTEP     asm(" RPT #255 || NOP")
#define CAN_TX_MAILBOX1 (1U)

#define CAN_RX_MAILBOX1 (2U)
//
// Globals
//

//
//Task 1 (C) Variables
// NOTE: Do not initialize the Message RAM variables globally, they will be
// reset during the message ram initialization phase in the CLA memory
// configuration routine
//
#ifdef __cplusplus
#pragma DATA_SECTION("CpuToCla1MsgRAM");
float fVal;
#pragma DATA_SECTION("Cla1ToCpuMsgRAM");
float fResult;
#else
#pragma DATA_SECTION(fVal,"CpuToCla1MsgRAM");
float fVal;
#pragma DATA_SECTION(ADCA0_Result,"Cla1ToCpuMsgRAM");
float ADCA0_Result;
#pragma DATA_SECTION(ADCA1_Result,"Cla1ToCpuMsgRAM");
float ADCA1_Result;
#pragma DATA_SECTION(ADCA2_Result,"Cla1ToCpuMsgRAM");
float ADCA2_Result;
#pragma DATA_SECTION(ADCA3_Result,"Cla1ToCpuMsgRAM");
float ADCA3_Result;
#pragma DATA_SECTION(ADCA4_Result,"Cla1ToCpuMsgRAM");
float ADCA4_Result;
#pragma DATA_SECTION(ADCA5_Result,"Cla1ToCpuMsgRAM");
float ADCA5_Result;
#pragma DATA_SECTION(ADCB14_Result,"Cla1ToCpuMsgRAM");
float ADCB14_Result;
#pragma DATA_SECTION(ADCB15_Result,"Cla1ToCpuMsgRAM");
float ADCB15_Result;

#endif //__cplusplus
//float y[BUFFER_SIZE];

//
//Task 2 (C) Variables
//

//
//Task 3 (C) Variables
//

//
//Task 4 (C) Variables
//

//
//Task 5 (C) Variables
//

//
//Task 6 (C) Variables
//

//
//Task 7 (C) Variables
//

//
//Task 8 (C) Variables
//

//
//Common (C) Variables
//The Exponential table
//
enum {
    ADC_INA0=0,
    ADC_INA1,
    ADC_INA2,
    ADC_INA3,
    ADC_INA4,
    ADC_INA5,
    ADCA_max
};
uint16_t pDataADC_A[ADCA_max];
enum {
    ADC_INB0=0,
    ADC_INB1,
    ADC_INB2,
    ADC_INB3,
    ADC_INB4,
    ADC_INB5,
    ADC_INB14,
    ADC_INB15,
    ADCB_max
};
uint16_t pDataADC_B[ADCB_max];

HAL_PinConfig abGpiPinConfig[GPI_PIN_MaxCnt];
HAL_PinConfig abGpoPinConfig[GPO_PIN_MaxCnt];
//HAL_PinConfig abPwmPinConfig[PWM_PIN_MaxCnt];

float adc0;
uint16_t tx[8];
uint16_t tx_cnt=0;
uint16_t rx[8];
uint16_t rx_cnt=0;
//
// Function Prototypes
//
void mcu_task1(void* pvParameters);
void mcu_task2(void* pvParameters);
__interrupt void INT_myCAN0_0_ISR();
__interrupt void INT_myCAN0_1_ISR();
void IO_vInit(void);
__interrupt void cla1Isr1();
__interrupt void cla1Isr2();
__interrupt void cla1Isr3();
__interrupt void cla1Isr4();
__interrupt void cla1Isr5();
__interrupt void cla1Isr6();
__interrupt void cla1Isr7();
__interrupt void cla1Isr8();

//
// Main
//
void main(void)
{

    //
    // Intialize device clock and peripherals
    //
    Device_init();

    //
    // Disable pin locks and enable internal pullups.
    //
    //Device_initGPIO(); //skipped for this example

    //
    // Initialize PIE and clear PIE registers. Disables CPU interrupts
    //
    Interrupt_initModule();

    //
    // Initialize the PIE vector table with pointers to the shell Interrupt
    // Service Routines (ISR).
    //
    Interrupt_initVectorTable();

    //
    // Initialize resources
    //
    Board_init();
//    IO_vInit();
    //
    // Enable Global Interrupt (INTM) and realtime interrupt (DBGM)
    //
    EINT;
    ERTM;

    FreeRTOS_init();

    for(;;)
    {
    }
}

void mcu_task1(void* pvParameters)
{
    tx[0] = 0x11;
    tx[1] = 0x22;
    tx[2] = 0x33;
    tx[3] = 0x44;
    tx[4] = 0x55;
    tx[5] = 0x66;
    tx[6] = 0x77;
    tx[7] = 0x88;

    while(1)
    {
//        GPIO_togglePin(19);
        CAN_sendMessage(myCAN0_BASE, 1, 8, tx);
        vTaskDelay(2000);
    }
}

void mcu_task2(void* pvParameters)
{
    while(1)
    {
        CLA_forceTasks(CLA1_BASE,CLA_TASKFLAG_1);
        ADC_forceSOC(myADC0_BASE, ADC_SOC_NUMBER5);
        vTaskDelay(100);
    }
}

//
// CAN - interrupt line 0 and 1
//
__interrupt void INT_myCAN0_0_ISR()
{
    uint32_t status = CAN_getInterruptCause(myCAN0_BASE);

    //  checking Error
    if (status == CAN_INT_INT0ID_STATUS)
    {
        // Clear the interrupt
        CAN_clearInterruptStatus(myCAN0_BASE, CAN_INT_INT0ID_STATUS);
    }

    // Transmit Interrupt
    if (status == CAN_TX_MAILBOX1)
    {
        tx_cnt++;
        // Clear the interrupt
        CAN_clearInterruptStatus(myCAN0_BASE, CAN_TX_MAILBOX1);
    }

    // Receive Interrupt
    if (status == CAN_RX_MAILBOX1)
    {
        CAN_readMessage(myCAN0_BASE, 2, rx);
        rx_cnt++;
        // Clear the interrupt
        CAN_clearInterruptStatus(myCAN0_BASE, CAN_RX_MAILBOX1);
    }

    CAN_clearGlobalInterruptStatus(myCAN0_BASE, CAN_GLOBAL_INT_CANINT0);

    // Acknowledge this interrupt located in group 9
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
}
//
__interrupt void INT_myCAN0_1_ISR()
{

}
//
// cla1Isr1 - CLA1 ISR 1
//

__interrupt void cla1Isr1 ()
{
    //
    // Acknowledge the end-of-task interrupt for task 1
    //
    ADC_clearInterruptStatus(myADC0_BASE, ADC_INT_NUMBER1);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP11);

//    pDataADC_A[ADCA_IN0] = ADCA0_Result;
//    pDataADC_A[ADCA_IN1] = ADCA1_Result;
//    pDataADC_A[ADCA_IN2] = ADCA2_Result;
//    pDataADC_A[ADCA_IN3] = ADCA3_Result;
//    pDataADC_A[ADCA_IN4] = ADCA4_Result;
    pDataADC_A[ADC_INA5] = ADCA5_Result;
//    GPIO_togglePin(myGPIO4);
    //
    // Uncomment to halt debugger and stop here
    //
    // asm(" ESTOP0");
}

//
// cla1Isr2 - CLA1 ISR 2
//
__interrupt void cla1Isr2 ()
{
    //
    // Acknowledge the end-of-task interrupt for task 8
    //
//    ADC_clearInterruptStatus(myADC0_BASE, ADC_INT_NUMBER1);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP11);

//    pDataADC_A[ADCA_INA1] = ADCA1_Result;
    //
    // Uncomment to halt debugger and stop here
    //
//    asm(" ESTOP0");
}

//
// cla1Isr3 - CLA1 ISR 3
//
__interrupt void cla1Isr3 ()
{
    //
    // Acknowledge the end-of-task interrupt for task 8
    //
//    ADC_clearInterruptStatus(myADC0_BASE, ADC_INT_NUMBER1);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP11);

//    pDataADC_A[ADCA_INA2] = ADCA2_Result;
    //
    // Uncomment to halt debugger and stop here
    //
//    asm(" ESTOP0");
}

//
// cla1Isr4 - CLA1 ISR 4
//
__interrupt void cla1Isr4 ()
{
    //
    // Acknowledge the end-of-task interrupt for task 8
    //
//    ADC_clearInterruptStatus(myADC0_BASE, ADC_INT_NUMBER1);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP11);

//    pDataADC_A[ADCA_INA3] = ADCA3_Result;
    //
    // Uncomment to halt debugger and stop here
    //
//    asm(" ESTOP0");
}

//
// cla1Isr5 - CLA1 ISR 5
//
__interrupt void cla1Isr5 ()
{
    //
    // Acknowledge the end-of-task interrupt for task 8
    //
//    ADC_clearInterruptStatus(myADC0_BASE, ADC_INT_NUMBER1);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP11);

//    pDataADC_A[ADCA_INA4] = ADCA4_Result;
    //
    // Uncomment to halt debugger and stop here
    //
//    asm(" ESTOP0");
}

//
// cla1Isr6 - CLA1 ISR 6
//
__interrupt void cla1Isr6 ()
{
    //
    // Acknowledge the end-of-task interrupt for task 8
    //
//    ADC_clearInterruptStatus(myADC0_BASE, ADC_INT_NUMBER1);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP11);

//    pDataADC_A[ADCA_INA5] = ADCA5_Result;
    //
    // Uncomment to halt debugger and stop here
    //
//    asm(" ESTOP0");
}

//
// cla1Isr7 - CLA1 ISR 7
//
__interrupt void cla1Isr7 ()
{
    //
    // Acknowledge the end-of-task interrupt for task 8
    //
//    ADC_clearInterruptStatus(myADC0_BASE, ADC_INT_NUMBER1);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP11);

//    pDataADC_B[ADCB_IN14] = ADCB14_Result;
    //
    // Uncomment to halt debugger and stop here
    //
//    asm(" ESTOP0");
}

//
// cla1Isr8 - CLA1 ISR 8
//
__interrupt void cla1Isr8 ()
{
    //
    // Acknowledge the end-of-task interrupt for task 8
    //
//    ADC_clearInterruptStatus(myADC0_BASE, ADC_INT_NUMBER1);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP11);

//    pDataADC_B[ADCB_IN15] = ADCB15_Result;
    //
    // Uncomment to halt debugger and stop here
    //
//    asm(" ESTOP0");
}

void IO_vInit(void)
{
    // GPIO: PinConfig
    abGpiPinConfig[myGPIO_0] = GPI_bPinConfig(myGPIO_0);
    abGpiPinConfig[myGPIO_1] = GPI_bPinConfig(myGPIO_1);
    abGpiPinConfig[myGPIO_2] = GPI_bPinConfig(myGPIO_2);
    abGpoPinConfig[myGPIO_3] = GPO_bPinConfig(myGPIO_3);
    abGpoPinConfig[myGPIO_4] = GPO_bPinConfig(myGPIO_4);
    abGpoPinConfig[myGPIO_5] = GPO_bPinConfig(myGPIO_5);
    abGpoPinConfig[myGPIO_6] = GPO_bPinConfig(myGPIO_6);
}

//
// End of file
//
